#include <iostream>
#include <iomanip>

//  Calcul de y(x) = m  <==>  m^m = x
//  xmin = (1/e)^(1/e) = 0.69220062755534636
//  ymin = y(xmin) = 1/e = 0.36787944117144232 = amin
//  bmax = 143.0 <==> xmax = bmax^bmax voisin de : 1.633e+308
double y(double x) {
    if(x < 0.69220062755534636) return 0.0;
    double a = 0.36787944117144232;
    double b = 143.0;
    double m, mm, n=0.0;
    do {
        m = (a+b)/2.0;
        if(m == n) break;
        mm = pow(m,m);
        if(mm > x) b = m; 
        if(mm < x) a = m; 
        n = m;
    }while((abs(mm-x) > 0.0) && (b-a > 0.0));
    return m;
}

//  Calcul de x = 1/y(1/z)
//  0 < z < zmax = e^(1/e) = 1.444667861009766
double x(double z) {
    if(!(z > 0.0 && z < 1.444667861009766)) return 0.0;
    return 1.0/y(1.0/z);
}

//  Calcul de y0(x) = m  <==>  m^m = x
//  xmin = (1/e)^(1/e) = 0.69220062755534636 < x < 1
//  ymax = y0(xmin) = 1/e = 0.36787944117144232
//  ymin = y0(1) = 0.0
//  amin doit tre petit et bmax = 0.7357589
double fy0(double x) {
    if(x < 0.69220062755534636 || x >= 1.0) return 0.0;
    double a = 0.000000000000000000000001;
    if(pow(a,a) < x) return 0.0;
    double b = 0.7357589;
    double m, mm, n=0.0;
    do {
        m = (a+b)/2.0;
        if(m == n) break;
        mm = pow(m,m);
        if(mm > x) a = m; 
        if(mm < x) b = m; 
        n = m;
    }while((abs(mm-x) > 0.0) && (b-a > 0.0));
    return m;
}

//  Calcul de x0 = 1/y0(1/z)
//  1 < z < zmax = e^(1/e) = 1.444667861009766
double x0(double z) {
    if(!(z > 1.0 && z < 1.444667861009766)) return 0.0;
    return 1.0/fy0(1.0/z);
}

int main(int argc, char ** argv) {
    while(true) {
        double v,z;
        std::cout << std::endl << "Entrez z : ";
        std::cin >> z;
        if(z <= 0.0) break;
        v = x(z);
        std::cout << "z = " << std::setprecision(15) << z << "   x = " << v << "   z^x = " << pow(z,v) << std::endl;
		if(z > 1.0 && z < 1.444667861009766) {
            v = x0(z);
            std::cout << "z = " << std::setprecision(15) << z << "   x = " << v << "   z^x = " << pow(z,v) << std::endl;
        }
    }
    return 0;
}